(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    257051,       6505]
NotebookOptionsPosition[    252689,       6359]
NotebookOutlinePosition[    253474,       6384]
CellTagsIndexPosition[    253431,       6381]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["APT.nb", "Title",
 CellChangeTimes->{{3.683970607962332*^9, 3.683970615797029*^9}, {
  3.683974194640267*^9, 3.6839741951281853`*^9}, {3.684124621660074*^9, 
  3.684124622460247*^9}}],

Cell["\<\
Description:
In this notebook, we do some example computations using the package \
\[OpenCurlyDoubleQuote]APT.m\[CloseCurlyDoubleQuote]. First, we compute the \
example from the manual to illustrate how the various functions work. Then, \
we check invariance under Reidemeister moves II and III. We also verify the \
axioms for the multivariate Alexander polynomial of links. Finally, we \
compute the invariant for the (2,-3)-pretzel tangle. \
\>", "Text",
 CellChangeTimes->{{3.683970622362843*^9, 3.683970800703075*^9}, {
  3.683970903314045*^9, 3.683970923738529*^9}, {3.683970959968808*^9, 
  3.683970961867495*^9}, {3.6839722300605*^9, 3.6839722478129787`*^9}, {
  3.683973137516122*^9, 3.683973171244916*^9}, {3.683974201839737*^9, 
  3.683974221224177*^9}, {3.6841246035556192`*^9, 3.6841246042997828`*^9}}],

Cell[CellGroupData[{

Cell["Load package APT.m", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.68390335323253*^9, 
  3.683903371168364*^9}, {3.683949830312366*^9, 3.683949830550836*^9}, {
  3.685186908447523*^9, 3.6851869085320377`*^9}, {3.685198191575903*^9, 
  3.685198207056624*^9}, {3.685699952681923*^9, 3.6856999530894327`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "APT.m"}]], "Input",
 CellChangeTimes->{{3.683970345494389*^9, 3.683970354923908*^9}, {
  3.68397227082953*^9, 3.683972282837954*^9}, {3.683974237680615*^9, 
  3.683974237816609*^9}, {3.68412459971563*^9, 3.684124600459858*^9}, {
  3.6856999557222557`*^9, 3.685699955865905*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"This is APT.m, version 1.1, \\na tool for computing \
\\!\\(\\*SubsuperscriptBox[\\(\[Del]\\), \\(T\\), \\(s\\)]\\), a \
generalisation of Alexander polynomials for tangles,\\nwritten in Mathematica \
10.3.1.0 for Linux x86 (64-bit). \\nA manual for this Mathematica package can \
be found in appendix C of\\n\\n   C.B. Zibrowius, \"\>", "\[InvisibleSpace]", 
   StyleBox["\<\"On a Heegaard Floer theory for tangles\"\>",
    StripOnInput->False,
    FontSlant->Italic], 
   "\[InvisibleSpace]", "\<\", PhD thesis (2016), Cambridge.\\n\\nFor \
questions, suggestions or comments, please email claudius.zibrowius\"\>", 
   "\[InvisibleSpace]", "\<\"@\"\>", 
   "\[InvisibleSpace]", "\<\"gmail.com. \\n\\n    Copyright (C) 2015-2016 \
Claudius Zibrowius\\n\\n    This program is free software: you can \
redistribute it and/or modify\\n    it under the terms of the GNU Affero \
General Public License as published by\\n    the Free Software Foundation, \
either version 3 of the License, or\\n    (at your option) any later version.\
\\n\\n    This program is distributed in the hope that it will be useful,\\n  \
  but WITHOUT ANY WARRANTY; without even the implied warranty of\\n    \
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\\n    GNU \
Affero General Public License for more details.\\n\\n    You should have \
received a copy of the GNU Affero General Public License\\n    along with \
this program.  If not, see <http://www.gnu.org/licenses/>.\"\>"}],
  SequenceForm[
  "This is APT.m, version 1.1, \na tool for computing \
\!\(\*SubsuperscriptBox[\(\[Del]\), \(T\), \(s\)]\), a generalisation of \
Alexander polynomials for tangles,\nwritten in Mathematica 10.3.1.0 for Linux \
x86 (64-bit). \nA manual for this Mathematica package can be found in \
appendix C of\n\n   C.B. Zibrowius, ", 
   Style["On a Heegaard Floer theory for tangles", Italic], 
   ", PhD thesis (2016), Cambridge.\n\nFor questions, suggestions or \
comments, please email claudius.zibrowius", "@", 
   "gmail.com. \n\n    Copyright (C) 2015-2016 Claudius Zibrowius\n\n    This \
program is free software: you can redistribute it and/or modify\n    it under \
the terms of the GNU Affero General Public License as published by\n    the \
Free Software Foundation, either version 3 of the License, or\n    (at your \
option) any later version.\n\n    This program is distributed in the hope \
that it will be useful,\n    but WITHOUT ANY WARRANTY; without even the \
implied warranty of\n    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. \
 See the\n    GNU Affero General Public License for more details.\n\n    You \
should have received a copy of the GNU Affero General Public License\n    \
along with this program.  If not, see <http://www.gnu.org/licenses/>."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.685699896045292*^9, 3.685699958471336*^9, 3.685703924979106*^9, 
   3.685705170221436*^9, {3.685705240860914*^9, 3.685705244423066*^9}, 
   3.6857061190286207`*^9, 3.686040820998178*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation for the example from the manual", "Section",
 CellChangeTimes->{{3.683970886481442*^9, 3.683970889546365*^9}, {
  3.683973123955348*^9, 3.683973129388076*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "h", ",", "f", ",", "b", ",", "c", ",", "R", ",", "q", ",", "q"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "g", ",", "f", ",", "h", ",", "c", ",", "R", ",", "q", ",", "q"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "d", ",", "f", ",", "g", ",", "c", ",", "R", ",", "q", ",", "q"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "a", ",", "e", ",", "f", ",", "d", ",", "L", ",", "p", ",", "q"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "f", ",", "e", ",", "a", ",", "b", ",", "L", ",", "q", ",", "p"}], 
      "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.6839709884284983`*^9}, {3.683971862243135*^9, 
   3.683971864340918*^9}, {3.6846490515177097`*^9, 3.684649058493202*^9}, 
   3.684652955092742*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vp1", "=", 
  RowBox[{"AlexpolyPdh", "[", "v", "]"}]}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.6839709884284983`*^9}, {3.683971862243135*^9, 
   3.683971864340918*^9}, {3.684649061893526*^9, 3.684649062157894*^9}, {
   3.684649185153097*^9, 3.684649185370098*^9}, {3.684652956444475*^9, 
   3.68465298862125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", 
      SuperscriptBox["\[Delta]", 
       RowBox[{"-", "1"}]]}], 
     SuperscriptBox["q", 
      RowBox[{"-", "6"}]]}], 
    SuperscriptBox["p", 
     RowBox[{"-", "2"}]]}], 
   SuperscriptBox["h", 
    RowBox[{"-", "1"}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"b", " ", 
     SuperscriptBox["p", "2"]}], 
    SuperscriptBox["\[Delta]", 
     RowBox[{"-", "1"}]]}], 
   SuperscriptBox["q", 
    RowBox[{"-", "6"}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"d", " ", 
     SuperscriptBox["p", "2"]}], 
    SuperscriptBox["\[Delta]", 
     RowBox[{"-", "1"}]]}], 
   SuperscriptBox["q", 
    RowBox[{"-", "6"}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"d", 
     SuperscriptBox["\[Delta]", 
      RowBox[{"-", "1"}]]}], 
    SuperscriptBox["q", 
     RowBox[{"-", "2"}]]}], 
   SuperscriptBox["p", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"b", " ", "h", " ", 
     SuperscriptBox["p", "2"]}], 
    SuperscriptBox["\[Delta]", 
     RowBox[{"-", "1"}]]}], 
   SuperscriptBox["q", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"d", " ", "h", " ", 
     SuperscriptBox["q", "2"]}], 
    SuperscriptBox["\[Delta]", 
     RowBox[{"-", "1"}]]}], 
   SuperscriptBox["p", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{
   RowBox[{"b", " ", 
    SuperscriptBox["h", "2"], " ", 
    SuperscriptBox["p", "2"], " ", 
    SuperscriptBox["q", "2"]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", "1"}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"b", " ", 
     SuperscriptBox["h", "2"], " ", 
     SuperscriptBox["q", "6"]}], 
    SuperscriptBox["\[Delta]", 
     RowBox[{"-", "1"}]]}], 
   SuperscriptBox["p", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"d", " ", 
     SuperscriptBox["h", "2"], " ", 
     SuperscriptBox["q", "6"]}], 
    SuperscriptBox["\[Delta]", 
     RowBox[{"-", "1"}]]}], 
   SuperscriptBox["p", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{
   RowBox[{"b", " ", 
    SuperscriptBox["h", "3"], " ", 
    SuperscriptBox["p", "2"], " ", 
    SuperscriptBox["q", "6"]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", "1"}]]}], "+", 
  RowBox[{
   RowBox[{"c", 
    SuperscriptBox["p", 
     RowBox[{"-", "2"}]]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]]}], "+", 
  RowBox[{
   RowBox[{"c", " ", "h", " ", 
    SuperscriptBox["p", "2"]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"a", 
     SuperscriptBox["q", 
      RowBox[{"-", "6"}]]}], 
    SuperscriptBox["h", 
     RowBox[{"-", "1"}]]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"c", 
      SuperscriptBox["q", 
       RowBox[{"-", "4"}]]}], 
     SuperscriptBox["p", 
      RowBox[{"-", "2"}]]}], 
    SuperscriptBox["h", 
     RowBox[{"-", "1"}]]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"c", " ", 
     SuperscriptBox["p", "2"]}], 
    SuperscriptBox["q", 
     RowBox[{"-", "4"}]]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "a"}], 
    SuperscriptBox["q", 
     RowBox[{"-", "2"}]]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]]}], "+", 
  RowBox[{
   RowBox[{"2", " ", "a", " ", "h", " ", 
    SuperscriptBox["q", "2"]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"c", " ", "h", " ", 
     SuperscriptBox["q", "4"]}], 
    SuperscriptBox["p", 
     RowBox[{"-", "2"}]]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]]}], "+", 
  RowBox[{
   RowBox[{"c", " ", 
    SuperscriptBox["h", "2"], " ", 
    SuperscriptBox["p", "2"], " ", 
    SuperscriptBox["q", "4"]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]]}], "+", 
  RowBox[{
   RowBox[{"a", " ", 
    SuperscriptBox["h", "2"], " ", 
    SuperscriptBox["q", "6"]}], 
   SuperscriptBox["\[Delta]", 
    RowBox[{"-", 
     FractionBox["1", "2"]}]]}]}]], "Output",
 CellChangeTimes->{{3.6839709781468554`*^9, 3.6839709917015467`*^9}, {
   3.683971858436749*^9, 3.683971868749054*^9}, 3.6839720047635603`*^9, 
   3.684480846547408*^9, {3.684649178235587*^9, 3.684649186325282*^9}, 
   3.684652822901017*^9, {3.684652961857574*^9, 3.684652991714826*^9}, 
   3.68570524906257*^9, 3.686040826017569*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vp2", "=", 
  RowBox[{"AlexpolyGh", "[", "v", "]"}]}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.683971002599815*^9}, {3.684649064358189*^9, 
   3.6846490645575*^9}, {3.684649188920518*^9, 3.684649189192775*^9}, {
   3.684652957140421*^9, 3.684652990005279*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c", " ", "hcgfe"}], 
   SuperscriptBox["p", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{"c", " ", "h", " ", "hcgef", " ", 
   SuperscriptBox["p", "2"]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", "hgfea"}], 
    SuperscriptBox["q", 
     RowBox[{"-", "6"}]]}], 
   SuperscriptBox["h", 
    RowBox[{"-", "1"}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", " ", "hgdfe"}], 
     SuperscriptBox["q", 
      RowBox[{"-", "6"}]]}], 
    SuperscriptBox["p", 
     RowBox[{"-", "2"}]]}], 
   SuperscriptBox["h", 
    RowBox[{"-", "1"}]]}], "+", 
  RowBox[{
   RowBox[{"d", " ", "hgdef", " ", 
    SuperscriptBox["p", "2"]}], 
   SuperscriptBox["q", 
    RowBox[{"-", "6"}]]}], "+", 
  RowBox[{
   RowBox[{"b", " ", "hgfeb", " ", 
    SuperscriptBox["p", "2"]}], 
   SuperscriptBox["q", 
    RowBox[{"-", "6"}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"c", " ", "hgcfe"}], 
     SuperscriptBox["q", 
      RowBox[{"-", "4"}]]}], 
    SuperscriptBox["p", 
     RowBox[{"-", "2"}]]}], 
   SuperscriptBox["h", 
    RowBox[{"-", "1"}]]}], "+", 
  RowBox[{
   RowBox[{"c", " ", "hgcef", " ", 
    SuperscriptBox["p", "2"]}], 
   SuperscriptBox["q", 
    RowBox[{"-", "4"}]]}], "+", 
  RowBox[{
   RowBox[{"a", " ", "hfgea"}], 
   SuperscriptBox["q", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{
   RowBox[{"a", " ", "hgfae"}], 
   SuperscriptBox["q", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"d", " ", "hgfde"}], 
    SuperscriptBox["q", 
     RowBox[{"-", "2"}]]}], 
   SuperscriptBox["p", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{
   RowBox[{"b", " ", "h", " ", "hfgeb", " ", 
    SuperscriptBox["p", "2"]}], 
   SuperscriptBox["q", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{"a", " ", "fhgea", " ", "h", " ", 
   SuperscriptBox["q", "2"]}], "+", 
  RowBox[{"a", " ", "h", " ", "hfgae", " ", 
   SuperscriptBox["q", "2"]}], "+", 
  RowBox[{
   RowBox[{"d", " ", "h", " ", "hfgde", " ", 
    SuperscriptBox["q", "2"]}], 
   SuperscriptBox["p", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{"b", " ", "fhgeb", " ", 
   SuperscriptBox["h", "2"], " ", 
   SuperscriptBox["p", "2"], " ", 
   SuperscriptBox["q", "2"]}], "+", 
  RowBox[{
   RowBox[{"c", " ", "chgfe", " ", "h", " ", 
    SuperscriptBox["q", "4"]}], 
   SuperscriptBox["p", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{"c", " ", "chgef", " ", 
   SuperscriptBox["h", "2"], " ", 
   SuperscriptBox["p", "2"], " ", 
   SuperscriptBox["q", "4"]}], "+", 
  RowBox[{"a", " ", "fhgae", " ", 
   SuperscriptBox["h", "2"], " ", 
   SuperscriptBox["q", "6"]}], "+", 
  RowBox[{
   RowBox[{"b", " ", "bhgfe", " ", 
    SuperscriptBox["h", "2"], " ", 
    SuperscriptBox["q", "6"]}], 
   SuperscriptBox["p", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{
   RowBox[{"d", " ", "fhgde", " ", 
    SuperscriptBox["h", "2"], " ", 
    SuperscriptBox["q", "6"]}], 
   SuperscriptBox["p", 
    RowBox[{"-", "2"}]]}], "+", 
  RowBox[{"b", " ", "bhgef", " ", 
   SuperscriptBox["h", "3"], " ", 
   SuperscriptBox["p", "2"], " ", 
   SuperscriptBox["q", "6"]}]}]], "Output",
 CellChangeTimes->{
  3.6839710037955303`*^9, {3.6839718609259863`*^9, 3.683971872544463*^9}, 
   3.6839720029545403`*^9, 3.684480848184136*^9, 3.684649189570619*^9, {
   3.6846529508543*^9, 3.684652993545747*^9}, 3.685705249235601*^9, 
   3.686040827275795*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimpleGrid", "[", 
  RowBox[{"vp2", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "0"}], ",", 
     RowBox[{"b", "\[Rule]", "0"}], ",", 
     RowBox[{"c", "\[Rule]", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.683971008304674*^9}, {3.68464906671739*^9, 
   3.684649066909486*^9}, {3.684652981533326*^9, 3.6846529829251413`*^9}, {
   3.686040642198821*^9, 3.686040644255816*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{
      RowBox[{"d", " ", "hgdfe"}], 
      SuperscriptBox["h", 
       RowBox[{"-", "1"}]]}], "", "", "", 
     RowBox[{"d", " ", "hgfde"}], "", "", "", 
     RowBox[{"d", " ", "h", " ", "hfgde"}], "", "", "", 
     RowBox[{"d", " ", "fhgde", " ", 
      SuperscriptBox["h", "2"]}]},
    {"", "", "", "", "", "", "", "", "", "", "", "", ""},
    {"", "", "", "", "", "", "", "", "", "", "", "", ""},
    {"", "", "", "", "", "", "", "", "", "", "", "", ""},
    {
     RowBox[{"d", " ", "hgdef"}], "", "", "", "", "", "", "", "", "", "", "", 
     ""}
   },
   AutoDelete->False,
   FrameStyle->Directive[
     Thickness[0.1], 
     AbsoluteDashing[{100, 0.01}], 
     GrayLevel[0.5]],
   GridBoxBackground->{
    "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
     "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
     "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.683971009286614*^9, 3.6839718764767323`*^9, 3.6839720019799137`*^9, 
   3.684480851374628*^9, 3.6846491917149067`*^9, {3.68465298395944*^9, 
   3.684652995178218*^9}, 3.685705251380673*^9, 3.6860408290297613`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AlexpolytableGh", "[", 
  RowBox[{"v", ",", "vp2"}], "]"}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.683971015430806*^9}, {3.683971716447658*^9, 
   3.68397173563983*^9}, {3.68464906959741*^9, 3.684649071589589*^9}, {
   3.685705262851447*^9, 3.685705268634468*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"a", 
      TagBox[GridBox[{
         {
          RowBox[{"hgfea", 
           SuperscriptBox["h", 
            RowBox[{"-", "1"}]]}], "", "", "", 
          RowBox[{"hfgea", "+", "hgfae"}], "", "", "", 
          RowBox[{
           RowBox[{"fhgea", " ", "h"}], "+", 
           RowBox[{"h", " ", "hfgae"}]}], "", "", "", 
          RowBox[{"fhgae", " ", 
           SuperscriptBox["h", "2"]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{1, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"b", 
      TagBox[GridBox[{
         {"", "", "", "", "", "", "", "", "", "", "", "", 
          RowBox[{"bhgfe", " ", 
           SuperscriptBox["h", "2"]}]},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"hgfeb", "", "", "", 
          RowBox[{"h", " ", "hfgeb"}], "", "", "", 
          RowBox[{"fhgeb", " ", 
           SuperscriptBox["h", "2"]}], "", "", "", 
          RowBox[{"bhgef", " ", 
           SuperscriptBox["h", "3"]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"c", 
      TagBox[GridBox[{
         {
          RowBox[{"hgcfe", 
           SuperscriptBox["h", 
            RowBox[{"-", "1"}]]}], "", "", "", "hcgfe", "", "", "", 
          RowBox[{"chgfe", " ", "h"}]},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"hgcef", "", "", "", 
          RowBox[{"h", " ", "hcgef"}], "", "", "", 
          RowBox[{"chgef", " ", 
           SuperscriptBox["h", "2"]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {5 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 5} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"d", 
      TagBox[GridBox[{
         {
          RowBox[{"hgdfe", 
           SuperscriptBox["h", 
            RowBox[{"-", "1"}]]}], "", "", "", "hgfde", "", "", "", 
          RowBox[{"h", " ", "hfgde"}], "", "", "", 
          RowBox[{"fhgde", " ", 
           SuperscriptBox["h", "2"]}]},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"hgdef", "", "", "", "", "", "", "", "", "", "", "", ""}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.683971881515421*^9, {3.683971996653132*^9, 3.683972000366529*^9}, 
   3.684480853287013*^9, {3.685705253276909*^9, 3.685705270313262*^9}, 
   3.686040830881106*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AlexpolytablePd", "[", 
  RowBox[{"v", ",", "vp1"}], "]"}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.683971015430806*^9}, {3.683971716447658*^9, 
   3.683971731487124*^9}, {3.684649075437769*^9, 3.6846490770059967`*^9}, {
   3.685705273082385*^9, 3.6857052803465357`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"a", 
      TagBox[GridBox[{
         {
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]], "", "", "", 
          RowBox[{"2", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          RowBox[{"2", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{1, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"b", 
      TagBox[GridBox[{
         {"", "", "", "", "", "", "", "", "", "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]]},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"c", 
      TagBox[GridBox[{
         {
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]]},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {5 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 5} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"d", 
      TagBox[GridBox[{
         {
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]]},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]], "", "", "", "", "", "", "", "", "", "", "", ""}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.683971981613463*^9, 3.683972006724291*^9}, 
   3.6844808552686243`*^9, 3.6857052810293093`*^9, 3.686040832631721*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AlexpolytablePdh", "[", 
  RowBox[{"v", ",", "vp1"}], "]"}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.683971015430806*^9}, {3.683971716447658*^9, 
   3.6839717339837093`*^9}, {3.683971931121209*^9, 3.68397193138974*^9}, {
   3.684649079134016*^9, 3.684649081237884*^9}, {3.685705284625396*^9, 
   3.685705288609906*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"a", 
      TagBox[GridBox[{
         {
          RowBox[{
           SuperscriptBox["h", 
            RowBox[{"-", "1"}]], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          RowBox[{"2", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          RowBox[{
           RowBox[{"2", " ", "h"}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          RowBox[{
           SuperscriptBox["h", "2"], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{1, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"b", 
      TagBox[GridBox[{
         {"", "", "", "", "", "", "", "", "", "", "", "", 
          RowBox[{
           SuperscriptBox["h", "2"], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}]},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]], "", "", "", 
          RowBox[{"h", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}], "", "", "", 
          RowBox[{
           SuperscriptBox["h", "2"], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}], "", "", "", 
          RowBox[{
           SuperscriptBox["h", "3"], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"c", 
      TagBox[GridBox[{
         {
          RowBox[{
           SuperscriptBox["h", 
            RowBox[{"-", "1"}]], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]], "", "", "", 
          RowBox[{"h", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}]},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", 
            FractionBox["1", "2"]}]], "", "", "", 
          RowBox[{"h", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          RowBox[{
           SuperscriptBox["h", "2"], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {5 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 5} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"d", 
      TagBox[GridBox[{
         {
          RowBox[{
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]], 
           SuperscriptBox["h", 
            RowBox[{"-", "1"}]]}], "", "", "", 
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]], "", "", "", 
          RowBox[{"h", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}], "", "", "", 
          RowBox[{
           SuperscriptBox["h", "2"], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}]},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", "", "", "", "", ""},
         {
          SuperscriptBox["\[Delta]", 
           RowBox[{"-", "1"}]], "", "", "", "", "", "", "", "", "", "", "", ""}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.683971878633382*^9, 3.6839719328570137`*^9, {3.683971998335847*^9, 
   3.6839720092490387`*^9}, 3.684480856955503*^9, 3.685705289769845*^9, 
   3.686040834566247*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotGrid", "[", "v", "]"}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.683971036093151*^9}, {3.684649084526033*^9, 
   3.6846490847179317`*^9}, 3.6846560438547277`*^9, 3.686040616909053*^9, 
   3.686040838476253*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}]}
   },
   AutoDelete->False,
   FrameStyle->Directive[
     Thickness[0.1], 
     AbsoluteDashing[{100, 0.01}], 
     GrayLevel[0.5]],
   GridBoxBackground->{
    "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
     "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
     "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.683971037194088*^9, 3.683972011677722*^9, 
  3.6844808592721243`*^9, 3.684656044657278*^9, 3.68570529189158*^9, 
  3.68604083929142*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DConfig", "[", "v", "]"}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.683971036093151*^9}, {3.684649087005891*^9, 
   3.684649087190048*^9}, 3.68465599830921*^9}],

Cell[BoxData[
 GraphicsBox[{CircleBox[{0, 0}], 
   {Arrowheads[
    Medium], {
     ArrowBox[NCache[{{-2^Rational[-1, 2], 2^
         Rational[-1, 2]}, {-1.2727922061357855`, 
        1.2727922061357855`}}, {{-0.7071067811865475, 
       0.7071067811865475}, {-1.2727922061357855`, 1.2727922061357855`}}]], 
     InsetBox["p", 
      NCache[{-2^Rational[1, 2], 2^Rational[1, 2]}, {-1.4142135623730951`, 
       1.4142135623730951`}]], 
     InsetBox["1", {-0.4949747468305832, 0.4949747468305832}], 
     InsetBox["a", {-1.5, 1.8369701987210297`*^-16}]}, {
     ArrowBox[NCache[{{-1.2727922061357855`, -1.2727922061357855`}, {-2^
          Rational[-1, 2], -2^
          Rational[-1, 
            2]}}, {{-1.2727922061357855`, -1.2727922061357855`}, \
{-0.7071067811865475, -0.7071067811865475}}]], 
     InsetBox["p", 
      NCache[{-2^Rational[1, 2], -2^
         Rational[1, 2]}, {-1.4142135623730951`, -1.4142135623730951`}]], 
     InsetBox["2", {-0.4949747468305832, -0.4949747468305832}], 
     InsetBox["b", {-2.755455298081545*^-16, -1.5}]}, {
     ArrowBox[NCache[{{1.2727922061357855`, -1.2727922061357855`}, {
        2^Rational[-1, 2], -2^Rational[-1, 2]}}, {{
       1.2727922061357855`, -1.2727922061357855`}, {
       0.7071067811865475, -0.7071067811865475}}]], 
     InsetBox["q", 
      NCache[{2^Rational[1, 2], -2^Rational[1, 2]}, {
       1.4142135623730951`, -1.4142135623730951`}]], 
     InsetBox["3", {0.4949747468305832, -0.4949747468305832}], 
     InsetBox["c", {1.5, -3.6739403974420594`*^-16}]}, {
     ArrowBox[NCache[{{2^Rational[-1, 2], 2^Rational[-1, 2]}, {
        1.2727922061357855`, 1.2727922061357855`}}, {{0.7071067811865475, 
       0.7071067811865475}, {1.2727922061357855`, 1.2727922061357855`}}]], 
     InsetBox["q", 
      NCache[{2^Rational[1, 2], 2^Rational[1, 2]}, {1.4142135623730951`, 
       1.4142135623730951`}]], 
     InsetBox["4", {0.4949747468305832, 0.4949747468305832}], 
     InsetBox["d", {4.592425496802575*^-16, 1.5}]}, 
    {GrayLevel[0], Opacity[0], CircleBox[{0, 0}, 1.3]}}},
  ImageSize->Tiny]], "Output",
 CellChangeTimes->{
  3.6434728895718403`*^9, 3.666678111345592*^9, 3.666680259225052*^9, 
   3.666686205721307*^9, 3.6666864908564043`*^9, 3.666691204970627*^9, {
   3.666725023248435*^9, 3.666725069486464*^9}, 3.6667279440595913`*^9, 
   3.666728018180455*^9, 3.666771219501346*^9, 3.6774751069540157`*^9, 
   3.6806111152886868`*^9, 3.680611366203182*^9, 3.680612780698565*^9, {
   3.680612821188201*^9, 3.680612848092259*^9}, {3.6813253853882713`*^9, 
   3.681325391577455*^9}, 3.681909339301835*^9, 3.6819263590630608`*^9, 
   3.683961525277439*^9, 3.683962116901268*^9, 3.6839640398015833`*^9, 
   3.683970375903022*^9, 3.683970997684389*^9, 3.683971041953662*^9, 
   3.683972013483363*^9, 3.684480863419331*^9, 3.684655961734111*^9, 
   3.6846559996650257`*^9, 3.685705293272221*^9, 3.686040841140497*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v1", "=", 
  RowBox[{"Twist", "[", 
   RowBox[{"v", ",", "a", ",", "R"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.683972017102771*^9, 3.6839720429758244`*^9}, {
   3.684649089582391*^9, 3.684649089766652*^9}, 3.6857053013631973`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"h", ",", "f", ",", "b", ",", "c", ",", "R", ",", "q", ",", "q"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"g", ",", "f", ",", "h", ",", "c", ",", "R", ",", "q", ",", "q"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"d", ",", "f", ",", "g", ",", "c", ",", "R", ",", "q", ",", "q"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "e", ",", "f", ",", "d", ",", "L", ",", "p", ",", "q"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "e", ",", "i", ",", "b", ",", "L", ",", "q", ",", "p"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "i", ",", "d", ",", "a", ",", "R", ",", "p", ",", "p"}],
     "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.683972026128821*^9, 3.683972044419693*^9}, 
   3.6844808664419947`*^9, 3.6857053043901*^9, 3.686040842887237*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DConfig", "[", "v1", "]"}]], "Input",
 CellChangeTimes->{
  3.683972075504278*^9, {3.684649091926487*^9, 3.684649092110928*^9}, 
   3.6857053030015717`*^9}],

Cell[BoxData[
 GraphicsBox[{CircleBox[{0, 0}], 
   {Arrowheads[
    Medium], {
     ArrowBox[NCache[{{-1.2727922061357855`, 
        1.2727922061357855`}, {-2^Rational[-1, 2], 2^
         Rational[-1, 2]}}, {{-1.2727922061357855`, 
       1.2727922061357855`}, {-0.7071067811865475, 0.7071067811865475}}]], 
     InsetBox["p", 
      NCache[{-2^Rational[1, 2], 2^Rational[1, 2]}, {-1.4142135623730951`, 
       1.4142135623730951`}]], 
     InsetBox["1", {-0.4949747468305832, 0.4949747468305832}], 
     InsetBox["a", {-1.5, 1.8369701987210297`*^-16}]}, {
     ArrowBox[NCache[{{-2^Rational[-1, 2], -2^
          Rational[-1, 
            2]}, {-1.2727922061357855`, -1.2727922061357855`}}, \
{{-0.7071067811865475, -0.7071067811865475}, {-1.2727922061357855`, \
-1.2727922061357855`}}]], 
     InsetBox["p", 
      NCache[{-2^Rational[1, 2], -2^
         Rational[1, 2]}, {-1.4142135623730951`, -1.4142135623730951`}]], 
     InsetBox["2", {-0.4949747468305832, -0.4949747468305832}], 
     InsetBox["b", {-2.755455298081545*^-16, -1.5}]}, {
     ArrowBox[NCache[{{1.2727922061357855`, -1.2727922061357855`}, {
        2^Rational[-1, 2], -2^Rational[-1, 2]}}, {{
       1.2727922061357855`, -1.2727922061357855`}, {
       0.7071067811865475, -0.7071067811865475}}]], 
     InsetBox["q", 
      NCache[{2^Rational[1, 2], -2^Rational[1, 2]}, {
       1.4142135623730951`, -1.4142135623730951`}]], 
     InsetBox["3", {0.4949747468305832, -0.4949747468305832}], 
     InsetBox["c", {1.5, -3.6739403974420594`*^-16}]}, {
     ArrowBox[NCache[{{2^Rational[-1, 2], 2^Rational[-1, 2]}, {
        1.2727922061357855`, 1.2727922061357855`}}, {{0.7071067811865475, 
       0.7071067811865475}, {1.2727922061357855`, 1.2727922061357855`}}]], 
     InsetBox["q", 
      NCache[{2^Rational[1, 2], 2^Rational[1, 2]}, {1.4142135623730951`, 
       1.4142135623730951`}]], 
     InsetBox["4", {0.4949747468305832, 0.4949747468305832}], 
     InsetBox["d", {4.592425496802575*^-16, 1.5}]}, 
    {GrayLevel[0], Opacity[0], CircleBox[{0, 0}, 1.3]}}},
  ImageSize->Tiny]], "Output",
 CellChangeTimes->{3.68397207590271*^9, 3.684480868018051*^9, 
  3.685705305674987*^9, 3.686040844390424*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotGrid", "[", "v1", "]"}]], "Input",
 CellChangeTimes->{
  3.683972115897945*^9, {3.684649094885995*^9, 3.6846490964703407`*^9}, {
   3.685705310715303*^9, 3.6857053110019827`*^9}, 3.686040616950029*^9, 
   3.68604084846101*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16.125, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48.375, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {80.625, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->90,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16.125, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48.375, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {80.625, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->90,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16.125, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48.375, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {80.625, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->90,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16.125, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48.375, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {80.625, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->90,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16.125, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48.375, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {80.625, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->90,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16.125, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48.375, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {80.625, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->90,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}]}
   },
   AutoDelete->False,
   FrameStyle->Directive[
     Thickness[0.1], 
     AbsoluteDashing[{100, 0.01}], 
     GrayLevel[0.5]],
   GridBoxBackground->{
    "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
     "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
     "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.683972116320504*^9, 3.684480869904924*^9, 3.684649100184165*^9, 
   3.685705311798547*^9, {3.686040846150305*^9, 3.68604084904287*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v2", "=", 
  RowBox[{"Twist", "[", 
   RowBox[{"v1", ",", "d", ",", "L"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6839720887473793`*^9, 3.68397209572901*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"h", ",", "f", ",", "b", ",", "c", ",", "R", ",", "q", ",", "q"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"g", ",", "f", ",", "h", ",", "c", ",", "R", ",", "q", ",", "q"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "f", ",", "g", ",", "c", ",", "R", ",", "q", ",", "q"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "e", ",", "f", ",", "j", ",", "L", ",", "p", ",", "q"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", "e", ",", "i", ",", "b", ",", "L", ",", "q", ",", "p"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "i", ",", "j", ",", "a", ",", "R", ",", "p", ",", "p"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "j", ",", "c", ",", "d", ",", "L", ",", "q", ",", "p"}],
     "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.683972096049552*^9, 3.684480872347906*^9, 
  3.6857053139285192`*^9, 3.686040850560631*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DConfig", "[", "v2", "]"}]], "Input",
 CellChangeTimes->{{3.6839721027771378`*^9, 3.683972103035324*^9}}],

Cell[BoxData[
 GraphicsBox[{CircleBox[{0, 0}], 
   {Arrowheads[
    Medium], {
     ArrowBox[NCache[{{-2^Rational[-1, 2], 2^
         Rational[-1, 2]}, {-1.2727922061357855`, 
        1.2727922061357855`}}, {{-0.7071067811865475, 
       0.7071067811865475}, {-1.2727922061357855`, 1.2727922061357855`}}]], 
     InsetBox["q", 
      NCache[{-2^Rational[1, 2], 2^Rational[1, 2]}, {-1.4142135623730951`, 
       1.4142135623730951`}]], 
     InsetBox["1", {-0.4949747468305832, 0.4949747468305832}], 
     InsetBox["a", {-1.5, 1.8369701987210297`*^-16}]}, {
     ArrowBox[NCache[{{-2^Rational[-1, 2], -2^
          Rational[-1, 
            2]}, {-1.2727922061357855`, -1.2727922061357855`}}, \
{{-0.7071067811865475, -0.7071067811865475}, {-1.2727922061357855`, \
-1.2727922061357855`}}]], 
     InsetBox["p", 
      NCache[{-2^Rational[1, 2], -2^
         Rational[1, 2]}, {-1.4142135623730951`, -1.4142135623730951`}]], 
     InsetBox["2", {-0.4949747468305832, -0.4949747468305832}], 
     InsetBox["b", {-2.755455298081545*^-16, -1.5}]}, {
     ArrowBox[NCache[{{1.2727922061357855`, -1.2727922061357855`}, {
        2^Rational[-1, 2], -2^Rational[-1, 2]}}, {{
       1.2727922061357855`, -1.2727922061357855`}, {
       0.7071067811865475, -0.7071067811865475}}]], 
     InsetBox["q", 
      NCache[{2^Rational[1, 2], -2^Rational[1, 2]}, {
       1.4142135623730951`, -1.4142135623730951`}]], 
     InsetBox["3", {0.4949747468305832, -0.4949747468305832}], 
     InsetBox["c", {1.5, -3.6739403974420594`*^-16}]}, {
     ArrowBox[NCache[{{1.2727922061357855`, 1.2727922061357855`}, {
        2^Rational[-1, 2], 2^Rational[-1, 2]}}, {{1.2727922061357855`, 
       1.2727922061357855`}, {0.7071067811865475, 0.7071067811865475}}]], 
     InsetBox["p", 
      NCache[{2^Rational[1, 2], 2^Rational[1, 2]}, {1.4142135623730951`, 
       1.4142135623730951`}]], 
     InsetBox["4", {0.4949747468305832, 0.4949747468305832}], 
     InsetBox["d", {4.592425496802575*^-16, 1.5}]}, 
    {GrayLevel[0], Opacity[0], CircleBox[{0, 0}, 1.3]}}},
  ImageSize->Tiny]], "Output",
 CellChangeTimes->{3.6839721033702507`*^9, 3.684480874062249*^9, 
  3.685705315191289*^9, 3.68604085252177*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotGrid", "[", "v2", "]"}]], "Input",
 CellChangeTimes->{3.683972121786133*^9, 3.6860406169635353`*^9, 
  3.68604085388424*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16.125, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48.375, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {80.625, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->90,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16.125, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48.375, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {80.625, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->90,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16.125, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48.375, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {80.625, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->90,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16.125, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48.375, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {80.625, -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->90,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}]}
   },
   AutoDelete->False,
   FrameStyle->Directive[
     Thickness[0.1], 
     AbsoluteDashing[{100, 0.01}], 
     GrayLevel[0.5]],
   GridBoxBackground->{
    "ColumnsIndexed" -> {8 -> GrayLevel[0.85]}, 
     "RowsIndexed" -> {4 -> GrayLevel[0.85]}, 
     "ItemsIndexed" -> {{4, 8} -> GrayLevel[0.5]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.6839721196006804`*^9, 3.683972122350285*^9}, 
   3.684480875286653*^9, 3.6857053170624847`*^9, 3.686040854644837*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Invariance under Reidemeister moves II and III", "Section",
 CellChangeTimes->{{3.683971462080308*^9, 3.683971478064802*^9}, {
   3.683971699655501*^9, 3.683971702614848*^9}, 3.6839731881824923`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Reidemeister", " ", "II"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"RMII", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "d", ",", "a", ",", "e", ",", "b", ",", "R", ",", "p", ",", "q"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "e", ",", "a", ",", "b", ",", "c", ",", "L", ",", "p", ",", "q"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RMIIp", "=", 
     RowBox[{"AlexpolyPdh", "[", "RMII", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RMIIp", "=", 
     RowBox[{"AlexpolyGdh", "[", "RMII", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
     RowBox[{"AlexpolytableGdh", "[", 
      RowBox[{"RMII", ",", "RMIIp"}], "]"}], ",", 
     RowBox[{"AlexpolytablePd", "[", 
      RowBox[{"RMII", ",", "RMIIp"}], "]"}], ",", 
     RowBox[{"AlexpolytableP", "[", 
      RowBox[{"RMII", ",", "RMIIp"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.620197580592828*^9, 3.6201976003879604`*^9}, {
   3.620221195418519*^9, 3.620221200090786*^9}, {3.620221542943396*^9, 
   3.620221544550488*^9}, {3.6202222587403374`*^9, 3.6202222638836317`*^9}, {
   3.6202227057629056`*^9, 3.62022270845806*^9}, {3.620222827677879*^9, 
   3.6202228288079433`*^9}, {3.6202349967609105`*^9, 3.6202350026002445`*^9}, 
   3.6202350528981214`*^9, {3.6202368928873625`*^9, 3.6202369532108135`*^9}, {
   3.620888919286928*^9, 3.6208889353968496`*^9}, {3.6208914085483055`*^9, 
   3.620891502102657*^9}, 3.6208920246375437`*^9, {3.620892223900941*^9, 
   3.620892238238761*^9}, {3.6208926669012794`*^9, 3.6208926676593227`*^9}, {
   3.634769355162654*^9, 3.6347693683004055`*^9}, {3.6389649244739275`*^9, 
   3.638964933216428*^9}, {3.638965015202117*^9, 3.6389650274138155`*^9}, {
   3.638965077872701*^9, 3.638965081140888*^9}, {3.63896513396791*^9, 
   3.6389651420543723`*^9}, {3.643448461287468*^9, 3.64344846790587*^9}, {
   3.643463031022582*^9, 3.643463036341716*^9}, {3.684481027987088*^9, 
   3.684481076782421*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"a", 
        TagBox[GridBox[{
           {""},
           {""},
           {
            RowBox[{
             RowBox[{
              RowBox[{"ea", " ", "h"}], 
              SuperscriptBox["\[Delta]", 
               RowBox[{"-", 
                FractionBox["1", "2"]}]]}], "+", 
             RowBox[{"ae", 
              SuperscriptBox["\[Delta]", 
               FractionBox["1", "2"]]}]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {"b", 
        TagBox[GridBox[{
           {"eb", "", 
            RowBox[{"be", 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {"c", 
        TagBox[GridBox[{
           {"", "", 
            RowBox[{
             RowBox[{"ec", " ", "h"}], 
             SuperscriptBox["\[Delta]", 
              RowBox[{"-", 
               FractionBox["1", "2"]}]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {"d", 
        TagBox[GridBox[{
           {"de"}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"a", 
        TagBox[GridBox[{
           {""},
           {""},
           {
            RowBox[{
             SuperscriptBox["\[Delta]", 
              RowBox[{"-", 
               FractionBox["1", "2"]}]], "+", 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {"b", 
        TagBox[GridBox[{
           {"1", "", 
            SuperscriptBox["\[Delta]", 
             FractionBox["1", "2"]]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {"c", 
        TagBox[GridBox[{
           {"", "", 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", 
              FractionBox["1", "2"]}]]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {"d", 
        TagBox[GridBox[{
           {"1"}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"a", 
        TagBox[GridBox[{
           {""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          GridBoxBackground->{"Columns" -> {{
               GrayLevel[0.5]}}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {"b", 
        TagBox[GridBox[{
           {"1", "", "1"}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {"c", 
        TagBox[GridBox[{
           {"", "", 
            RowBox[{"-", "1"}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {"d", 
        TagBox[GridBox[{
           {"1"}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
   MatrixForm[{{ATP`a, 
      Grid[{{Null}, {
        Null}, {$CellContext`ea ATP`h 
          ATP`\[Delta]^Rational[-1, 2] + $CellContext`ae 
          ATP`\[Delta]^Rational[1, 2]}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`b, 
      Grid[{{$CellContext`eb, Null, $CellContext`be 
         ATP`\[Delta]^Rational[1, 2]}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c, 
      Grid[{{Null, Null, $CellContext`ec ATP`h ATP`\[Delta]^Rational[-1, 2]}},
        Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`d, 
      Grid[{{$CellContext`de}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}}], 
   MatrixForm[{{ATP`a, 
      Grid[{{Null}, {Null}, {
        ATP`\[Delta]^Rational[-1, 2] + ATP`\[Delta]^Rational[1, 2]}}, Frame -> 
       All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`b, 
      Grid[{{1, Null, ATP`\[Delta]^Rational[1, 2]}}, Frame -> All, FrameStyle -> 
       Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c, 
      Grid[{{Null, Null, ATP`\[Delta]^Rational[-1, 2]}}, Frame -> All, 
       FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`d, 
      Grid[{{1}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}}], 
   MatrixForm[{{ATP`a, 
      Grid[{{Null}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], Background -> {
         GrayLevel[0.5]}]}, {ATP`b, 
      Grid[{{1, Null, 1}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c, 
      Grid[{{Null, Null, -1}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`d, 
      Grid[{{1}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6389651431004324`*^9, {3.6434484682613697`*^9, 3.643448474862029*^9}, 
   3.643448621014372*^9, 3.643462325191383*^9, 3.643463039300997*^9, 
   3.6813180425209312`*^9, 3.681909870308752*^9, 3.6839621293501577`*^9, 
   3.683970379369576*^9, 3.6839721562632093`*^9, 3.6844808888060293`*^9, 
   3.684481079244329*^9, 3.685705320187459*^9, 3.686040856308916*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Reidemeister", " ", "III"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"RMIII", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "c", ",", "b", ",", "a", ",", "g", ",", "L", ",", "q", ",", "p"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "d", ",", "c", ",", "g", ",", "e", ",", "L", ",", "q", ",", "r"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "g", ",", "a", ",", "f", ",", "e", ",", "R", ",", "p", ",", "r"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RMIIIp", "=", 
     RowBox[{"AlexpolyGdh", "[", "RMIII", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
     RowBox[{"AlexpolytableGdh", "[", 
      RowBox[{"RMIII", ",", "RMIIIp"}], "]"}], ",", 
     RowBox[{"AlexpolytablePd", "[", 
      RowBox[{"RMIII", ",", "RMIIIp"}], "]"}], ",", 
     RowBox[{"AlexpolytableP", "[", 
      RowBox[{"RMIII", ",", "RMIIIp"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6064943531453257`*^9, 3.606494382916028*^9}, {
   3.6064945335406437`*^9, 3.606494592093992*^9}, 3.606494669541422*^9, {
   3.6064947872621555`*^9, 3.6064948117705574`*^9}, 3.6065005620845957`*^9, {
   3.608361719137648*^9, 3.6083617760915737`*^9}, 3.608362086809825*^9, {
   3.60836213416884*^9, 3.608362356597781*^9}, {3.608370391708757*^9, 
   3.608370407673667*^9}, {3.6083706220473003`*^9, 3.6083706519694157`*^9}, {
   3.617692562010725*^9, 3.6176925638598304`*^9}, {3.6201055126534834`*^9, 
   3.6201055128654957`*^9}, {3.620105547454474*^9, 3.6201055484995337`*^9}, {
   3.6202213832312613`*^9, 3.6202213883795557`*^9}, {3.6202350770835047`*^9, 
   3.620235081076733*^9}, 3.620852871816905*^9, {3.6208896850407267`*^9, 
   3.6208896891459618`*^9}, 3.6208897288992352`*^9, {3.6208897649452972`*^9, 
   3.620889770160595*^9}, {3.6208899818817053`*^9, 3.620890003376934*^9}, {
   3.620892782947917*^9, 3.620892797943774*^9}, {3.6389651982455864`*^9, 
   3.6389652448432517`*^9}, {3.643462340012607*^9, 3.6434623478806458`*^9}, {
   3.6434630489331703`*^9, 3.64346304900941*^9}},
 FontSize->14],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"a", " ", "b"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             RowBox[{
              RowBox[{"bga", 
               SuperscriptBox["r", 
                RowBox[{"-", "2"}]]}], 
              SuperscriptBox["h", 
               RowBox[{"-", "1"}]]}], 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "c"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             RowBox[{"acg", 
              SuperscriptBox["r", 
               RowBox[{"-", "2"}]]}], 
             SuperscriptBox["h", 
              RowBox[{"-", "1"}]]}]},
           {""},
           {""},
           {""},
           {
            RowBox[{
             RowBox[{"gca", 
              SuperscriptBox["r", 
               RowBox[{"-", "2"}]]}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"cga", " ", "\[Delta]"}], 
               SuperscriptBox["r", 
                RowBox[{"-", "2"}]]}], 
              SuperscriptBox["h", 
               RowBox[{"-", "1"}]]}]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "d"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             RowBox[{"adg", 
              SuperscriptBox["h", 
               RowBox[{"-", "1"}]]}], 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]},
           {""},
           {""},
           {""},
           {
            RowBox[{"gda", 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "e"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             RowBox[{"aeg", 
              SuperscriptBox["h", 
               RowBox[{"-", "1"}]]}], "+", 
             RowBox[{
              RowBox[{"age", " ", "\[Delta]"}], 
              SuperscriptBox["h", 
               RowBox[{"-", "2"}]]}]}], "", ""},
           {"", "", ""},
           {"", "", ""},
           {"", "", ""},
           {"gea", "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 3} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "f"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             RowBox[{"agf", 
              SuperscriptBox["h", 
               RowBox[{"-", "1"}]]}], 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}], "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 3} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "c"}], 
        TagBox[GridBox[{
           {"", "", 
            RowBox[{
             RowBox[{"bcg", 
              SuperscriptBox["r", 
               RowBox[{"-", "2"}]]}], 
             SuperscriptBox["\[Delta]", 
              RowBox[{"-", 
               FractionBox["1", "2"]}]]}]},
           {"", "", ""},
           {"", "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "d"}], 
        TagBox[GridBox[{
           {"", "", "bdg"},
           {"", "", ""},
           {"", "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "e"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             RowBox[{"beg", 
              SuperscriptBox["\[Delta]", 
               RowBox[{"-", 
                FractionBox["1", "2"]}]]}], "+", 
             RowBox[{
              RowBox[{"bge", 
               SuperscriptBox["h", 
                RowBox[{"-", "1"}]]}], 
              SuperscriptBox["\[Delta]", 
               FractionBox["1", "2"]]}]}]},
           {""},
           {""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "f"}], 
        TagBox[GridBox[{
           {"bgf"}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"c", " ", "d"}], 
        TagBox[GridBox[{
           {"", "", 
            RowBox[{"cdg", 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"c", " ", "e"}], 
        TagBox[GridBox[{
           {
            RowBox[{"ceg", "+", "gce", "+", 
             RowBox[{
              RowBox[{"cge", " ", "\[Delta]"}], 
              SuperscriptBox["h", 
               RowBox[{"-", "1"}]]}]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"c", " ", "f"}], 
        TagBox[GridBox[{
           {""},
           {""},
           {
            RowBox[{
             RowBox[{
              RowBox[{"gcf", " ", "h"}], 
              SuperscriptBox["\[Delta]", 
               RowBox[{"-", 
                FractionBox["1", "2"]}]]}], "+", 
             RowBox[{"cgf", 
              SuperscriptBox["\[Delta]", 
               FractionBox["1", "2"]]}]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"d", " ", "e"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             RowBox[{"gde", " ", 
              SuperscriptBox["r", "2"]}], 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"d", " ", "f"}], 
        TagBox[GridBox[{
           {""},
           {""},
           {
            RowBox[{"gdf", " ", "h", " ", 
             SuperscriptBox["r", "2"]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"e", " ", "f"}], 
        TagBox[GridBox[{
           {"", "", ""},
           {"", "", ""},
           {
            RowBox[{
             RowBox[{"gef", " ", "h", " ", 
              SuperscriptBox["r", "2"]}], 
             SuperscriptBox["\[Delta]", 
              RowBox[{"-", 
               FractionBox["1", "2"]}]]}], "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 3} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"a", " ", "b"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             SuperscriptBox["r", 
              RowBox[{"-", "2"}]], 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "c"}], 
        TagBox[GridBox[{
           {
            SuperscriptBox["r", 
             RowBox[{"-", "2"}]]},
           {""},
           {""},
           {""},
           {
            RowBox[{
             SuperscriptBox["r", 
              RowBox[{"-", "2"}]], "+", 
             RowBox[{"\[Delta]", 
              SuperscriptBox["r", 
               RowBox[{"-", "2"}]]}]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "d"}], 
        TagBox[GridBox[{
           {
            SuperscriptBox["\[Delta]", 
             FractionBox["1", "2"]]},
           {""},
           {""},
           {""},
           {
            SuperscriptBox["\[Delta]", 
             FractionBox["1", "2"]]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "e"}], 
        TagBox[GridBox[{
           {
            RowBox[{"1", "+", "\[Delta]"}], "", ""},
           {"", "", ""},
           {"", "", ""},
           {"", "", ""},
           {"1", "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 3} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "f"}], 
        TagBox[GridBox[{
           {
            SuperscriptBox["\[Delta]", 
             FractionBox["1", "2"]], "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 3} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "c"}], 
        TagBox[GridBox[{
           {"", "", 
            RowBox[{
             SuperscriptBox["r", 
              RowBox[{"-", "2"}]], 
             SuperscriptBox["\[Delta]", 
              RowBox[{"-", 
               FractionBox["1", "2"]}]]}]},
           {"", "", ""},
           {"", "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "d"}], 
        TagBox[GridBox[{
           {"", "", "1"},
           {"", "", ""},
           {"", "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "e"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             SuperscriptBox["\[Delta]", 
              RowBox[{"-", 
               FractionBox["1", "2"]}]], "+", 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]},
           {""},
           {""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "f"}], 
        TagBox[GridBox[{
           {"1"}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"c", " ", "d"}], 
        TagBox[GridBox[{
           {"", "", 
            SuperscriptBox["\[Delta]", 
             FractionBox["1", "2"]]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"c", " ", "e"}], 
        TagBox[GridBox[{
           {
            RowBox[{"2", "+", "\[Delta]"}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"c", " ", "f"}], 
        TagBox[GridBox[{
           {""},
           {""},
           {
            RowBox[{
             SuperscriptBox["\[Delta]", 
              RowBox[{"-", 
               FractionBox["1", "2"]}]], "+", 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"d", " ", "e"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             SuperscriptBox["r", "2"], 
             SuperscriptBox["\[Delta]", 
              FractionBox["1", "2"]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"d", " ", "f"}], 
        TagBox[GridBox[{
           {""},
           {""},
           {
            SuperscriptBox["r", "2"]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"e", " ", "f"}], 
        TagBox[GridBox[{
           {"", "", ""},
           {"", "", ""},
           {
            RowBox[{
             SuperscriptBox["r", "2"], 
             SuperscriptBox["\[Delta]", 
              RowBox[{"-", 
               FractionBox["1", "2"]}]]}], "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 3} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"a", " ", "b"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             RowBox[{"-", "1"}], 
             SuperscriptBox["r", 
              RowBox[{"-", "2"}]]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "c"}], 
        TagBox[GridBox[{
           {
            RowBox[{
             RowBox[{"-", "1"}], 
             SuperscriptBox["r", 
              RowBox[{"-", "2"}]]}]},
           {""},
           {""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "d"}], 
        TagBox[GridBox[{
           {
            RowBox[{"-", "1"}]},
           {""},
           {""},
           {""},
           {"1"}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "e"}], 
        TagBox[GridBox[{
           {"", "", ""},
           {"", "", ""},
           {"1", "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 3} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"a", " ", "f"}], 
        TagBox[GridBox[{
           {
            RowBox[{"-", "1"}], "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 3} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "c"}], 
        TagBox[GridBox[{
           {"", "", 
            SuperscriptBox["r", 
             RowBox[{"-", "2"}]]},
           {"", "", ""},
           {"", "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "d"}], 
        TagBox[GridBox[{
           {"", "", "1"},
           {"", "", ""},
           {"", "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "e"}], 
        TagBox[GridBox[{
           {""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          GridBoxBackground->{"Columns" -> {{
               GrayLevel[0.5]}}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"b", " ", "f"}], 
        TagBox[GridBox[{
           {"1"}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"c", " ", "d"}], 
        TagBox[GridBox[{
           {"", "", "1"}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"c", " ", "e"}], 
        TagBox[GridBox[{
           {"1"}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"c", " ", "f"}], 
        TagBox[GridBox[{
           {""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          GridBoxBackground->{"Columns" -> {{
               GrayLevel[0.5]}}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"d", " ", "e"}], 
        TagBox[GridBox[{
           {
            SuperscriptBox["r", "2"]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"d", " ", "f"}], 
        TagBox[GridBox[{
           {""},
           {""},
           {
            RowBox[{"-", 
             SuperscriptBox["r", "2"]}]}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 1} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]},
       {
        RowBox[{"e", " ", "f"}], 
        TagBox[GridBox[{
           {"", "", ""},
           {"", "", ""},
           {
            RowBox[{"-", 
             SuperscriptBox["r", "2"]}], "", ""}
          },
          AutoDelete->False,
          FrameStyle->Directive[
            Thickness[0.1], 
            AbsoluteDashing[{100, 0.01}], 
            GrayLevel[0.5]],
          
          GridBoxBackground->{
           "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
            "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
            "ItemsIndexed" -> {{1, 3} -> GrayLevel[0.5]}},
          GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
         "Grid"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
   MatrixForm[{{ATP`a ATP`b, 
      Grid[{{$CellContext`bga ATP`h^(-1) $CellContext`r^(-2) 
         ATP`\[Delta]^Rational[1, 2]}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`a ATP`c, 
      Grid[{{$CellContext`acg ATP`h^(-1) $CellContext`r^(-2)}, {Null}, {
        Null}, {Null}, {$CellContext`gca $CellContext`r^(-2) + \
$CellContext`cga ATP`h^(-1) $CellContext`r^(-2) ATP`\[Delta]}}, Frame -> All, 
       FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`a ATP`d, 
      Grid[{{$CellContext`adg ATP`h^(-1) ATP`\[Delta]^Rational[1, 2]}, {
        Null}, {Null}, {
        Null}, {$CellContext`gda ATP`\[Delta]^Rational[1, 2]}}, Frame -> All, 
       FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`a $CellContext`e, 
      Grid[{{$CellContext`aeg/ATP`h + $CellContext`age ATP`h^(-2) 
          ATP`\[Delta], Null, Null}, {Null, Null, Null}, {Null, Null, Null}, {
        Null, Null, Null}, {$CellContext`gea, Null, Null}}, Frame -> All, 
       FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{3 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 3} -> 
         GrayLevel[0.5]}]}, {ATP`a $CellContext`f, 
      Grid[{{$CellContext`agf ATP`h^(-1) ATP`\[Delta]^Rational[1, 2], Null, 
         Null}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{3 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 3} -> 
         GrayLevel[0.5]}]}, {ATP`b ATP`c, 
      Grid[{{
        Null, Null, $CellContext`bcg $CellContext`r^(-2) 
         ATP`\[Delta]^Rational[-1, 2]}, {Null, Null, Null}, {
        Null, Null, Null}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`b ATP`d, 
      Grid[{{Null, Null, $CellContext`bdg}, {Null, Null, Null}, {
        Null, Null, Null}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`b $CellContext`e, 
      Grid[{{$CellContext`beg ATP`\[Delta]^Rational[-1, 2] + $CellContext`bge 
          ATP`h^(-1) ATP`\[Delta]^Rational[1, 2]}, {Null}, {Null}}, Frame -> 
       All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`b $CellContext`f, 
      Grid[{{$CellContext`bgf}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c ATP`d, 
      Grid[{{Null, Null, $CellContext`cdg ATP`\[Delta]^Rational[1, 2]}}, 
       Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c $CellContext`e, 
      Grid[{{$CellContext`ceg + $CellContext`gce + $CellContext`cge 
          ATP`h^(-1) ATP`\[Delta]}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c $CellContext`f, 
      Grid[{{Null}, {
        Null}, {$CellContext`gcf ATP`h 
          ATP`\[Delta]^Rational[-1, 2] + $CellContext`cgf 
          ATP`\[Delta]^Rational[1, 2]}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`d $CellContext`e, 
      Grid[{{$CellContext`gde $CellContext`r^2 ATP`\[Delta]^Rational[1, 2]}}, 
       Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`d $CellContext`f, 
      Grid[{{Null}, {Null}, {$CellContext`gdf ATP`h $CellContext`r^2}}, Frame -> 
       All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {$CellContext`e $CellContext`f, 
      Grid[{{Null, Null, Null}, {
        Null, Null, Null}, {$CellContext`gef ATP`h $CellContext`r^2 
         ATP`\[Delta]^Rational[-1, 2], Null, Null}}, Frame -> All, FrameStyle -> 
       Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{3 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 3} -> 
         GrayLevel[0.5]}]}}], 
   MatrixForm[{{ATP`a ATP`b, 
      Grid[{{$CellContext`r^(-2) ATP`\[Delta]^Rational[1, 2]}}, Frame -> All, 
       FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`a ATP`c, 
      Grid[{{$CellContext`r^(-2)}, {Null}, {Null}, {
        Null}, {$CellContext`r^(-2) + $CellContext`r^(-2) ATP`\[Delta]}}, 
       Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`a ATP`d, 
      Grid[{{ATP`\[Delta]^Rational[1, 2]}, {Null}, {Null}, {Null}, {
        ATP`\[Delta]^Rational[1, 2]}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`a $CellContext`e, 
      Grid[{{1 + ATP`\[Delta], Null, Null}, {Null, Null, Null}, {
        Null, Null, Null}, {Null, Null, Null}, {1, Null, Null}}, Frame -> All,
        FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{3 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 3} -> 
         GrayLevel[0.5]}]}, {ATP`a $CellContext`f, 
      Grid[{{ATP`\[Delta]^Rational[1, 2], Null, Null}}, Frame -> All, 
       FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{3 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 3} -> 
         GrayLevel[0.5]}]}, {ATP`b ATP`c, 
      Grid[{{Null, Null, $CellContext`r^(-2) ATP`\[Delta]^Rational[-1, 2]}, {
        Null, Null, Null}, {Null, Null, Null}}, Frame -> All, FrameStyle -> 
       Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`b ATP`d, 
      Grid[{{Null, Null, 1}, {Null, Null, Null}, {Null, Null, Null}}, Frame -> 
       All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`b $CellContext`e, 
      Grid[{{ATP`\[Delta]^Rational[-1, 2] + ATP`\[Delta]^Rational[1, 2]}, {
        Null}, {Null}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`b $CellContext`f, 
      Grid[{{1}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c ATP`d, 
      Grid[{{Null, Null, ATP`\[Delta]^Rational[1, 2]}}, Frame -> All, 
       FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c $CellContext`e, 
      Grid[{{2 + ATP`\[Delta]}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c $CellContext`f, 
      Grid[{{Null}, {Null}, {
        ATP`\[Delta]^Rational[-1, 2] + ATP`\[Delta]^Rational[1, 2]}}, Frame -> 
       All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`d $CellContext`e, 
      Grid[{{$CellContext`r^2 ATP`\[Delta]^Rational[1, 2]}}, Frame -> All, 
       FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`d $CellContext`f, 
      Grid[{{Null}, {Null}, {$CellContext`r^2}}, Frame -> All, FrameStyle -> 
       Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {$CellContext`e $CellContext`f, 
      Grid[{{Null, Null, Null}, {
        Null, Null, Null}, {$CellContext`r^2 ATP`\[Delta]^Rational[-1, 2], 
         Null, Null}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{3 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 3} -> 
         GrayLevel[0.5]}]}}], 
   MatrixForm[{{ATP`a ATP`b, 
      Grid[{{(-1) $CellContext`r^(-2)}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`a ATP`c, 
      Grid[{{(-1) $CellContext`r^(-2)}, {Null}, {Null}}, Frame -> All, 
       FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`a ATP`d, 
      Grid[{{-1}, {Null}, {Null}, {Null}, {1}}, Frame -> All, FrameStyle -> 
       Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`a $CellContext`e, 
      Grid[{{Null, Null, Null}, {Null, Null, Null}, {1, Null, Null}}, Frame -> 
       All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{3 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 3} -> 
         GrayLevel[0.5]}]}, {ATP`a $CellContext`f, 
      Grid[{{-1, Null, Null}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{3 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 3} -> 
         GrayLevel[0.5]}]}, {ATP`b ATP`c, 
      Grid[{{Null, Null, $CellContext`r^(-2)}, {Null, Null, Null}, {
        Null, Null, Null}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`b ATP`d, 
      Grid[{{Null, Null, 1}, {Null, Null, Null}, {Null, Null, Null}}, Frame -> 
       All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {3 -> GrayLevel[0.85]}, {3, 1} -> 
         GrayLevel[0.5]}]}, {ATP`b $CellContext`e, 
      Grid[{{Null}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], Background -> {
         GrayLevel[0.5]}]}, {ATP`b $CellContext`f, 
      Grid[{{1}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c ATP`d, 
      Grid[{{Null, Null, 1}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c $CellContext`e, 
      Grid[{{1}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`c $CellContext`f, 
      Grid[{{Null}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], Background -> {
         GrayLevel[0.5]}]}, {ATP`d $CellContext`e, 
      Grid[{{$CellContext`r^2}}, Frame -> All, FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {ATP`d $CellContext`f, 
      Grid[{{Null}, {Null}, {-$CellContext`r^2}}, Frame -> All, FrameStyle -> 
       Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{1 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 1} -> 
         GrayLevel[0.5]}]}, {$CellContext`e $CellContext`f, 
      Grid[{{Null, Null, Null}, {
        Null, Null, Null}, {-$CellContext`r^2, Null, Null}}, Frame -> All, 
       FrameStyle -> Directive[
         Thickness[0.1], 
         AbsoluteDashing[{100, 0.01}], 
         GrayLevel[0.5]], 
       Background -> {{3 -> GrayLevel[0.85]}, {1 -> GrayLevel[0.85]}, {1, 3} -> 
         GrayLevel[0.5]}]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.638965245848309*^9, 3.6389652485504637`*^9}, 
   3.643462348989554*^9, 3.643463051781003*^9, 3.681315709338366*^9, 
   3.6819098889086227`*^9, 3.683962130850368*^9, 3.683970382842177*^9, 
   3.6839721595262413`*^9, 3.6844808917835007`*^9, 3.6857053225533037`*^9, 
   3.686040857908367*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Verification of the axioms for the multivariate Alexanderpolynomial of links\
\>", "Section",
 CellChangeTimes->{{3.6839710581682034`*^9, 3.683971093742784*^9}, {
  3.683971145760292*^9, 3.6839711583684187`*^9}, {3.683971238066668*^9, 
  3.683971249210834*^9}, {3.6839731996455584`*^9, 3.683973204141973*^9}}],

Cell["\<\
see: Jiang, On Conway\[CloseCurlyQuote]s potential function for colored \
links, Acta Math. Sinica (English Series) 32 (2016), no.1, 25-39 (arXiv: \
1407.3081v1)\
\>", "Text",
 CellChangeTimes->{{3.68397126175566*^9, 3.683971315044594*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"(", "II", ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Note", ":", " ", "i"}], "=", "p"}], ",", " ", 
      RowBox[{"j", "=", "q"}]}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DLcrossing", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "a", ",", "b", ",", "e", ",", "d", ",", "L", ",", "q", ",", "p"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "e", ",", "b", ",", "c", ",", "d", ",", "L", ",", "p", ",", "q"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DRcrossing", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "a", ",", "b", ",", "e", ",", "d", ",", "R", ",", "p", ",", "q"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "e", ",", "b", ",", "c", ",", "d", ",", "R", ",", "q", ",", "p"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DLcrossingp", "=", 
     RowBox[{"AlexpolyP", "[", "DLcrossing", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DRcrossingp", "=", 
     RowBox[{"AlexpolyP", "[", "DRcrossing", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"AlexpolytableP", "[", 
    RowBox[{"DLcrossing", ",", 
     RowBox[{"DLcrossingp", "+", "DRcrossingp"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6176998299344263`*^9, 3.6176998373468504`*^9}, {
   3.6176998680166044`*^9, 3.6176999816221027`*^9}, 3.617700029015813*^9, {
   3.617700095875637*^9, 3.6177001207620606`*^9}, {3.617700329961026*^9, 
   3.6177003504621987`*^9}, {3.6177141306513805`*^9, 
   3.6177141445691767`*^9}, {3.620893387462493*^9, 3.620893394278883*^9}, {
   3.6389652756150117`*^9, 3.638965303544609*^9}, {3.6434623982423477`*^9, 
   3.643462400049143*^9}, {3.643463065257949*^9, 3.6434630676810093`*^9}, {
   3.68190993410705*^9, 3.681909934940156*^9}, {3.6819099907611227`*^9, 
   3.681909991479425*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"a", 
      TagBox[GridBox[{
         {"1", "", "", "", ""},
         {"", "", "", "", ""},
         {"", "", "", "", ""},
         {"", "", "", "", ""},
         {"", "", "", "", "1"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 3} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"b", 
      TagBox[GridBox[{
         {""}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{"Columns" -> {{
             GrayLevel[0.5]}}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"c", 
      TagBox[GridBox[{
         {"1", "", "", "", ""},
         {"", "", "", "", ""},
         {"", "", "", "", ""},
         {"", "", "", "", ""},
         {"", "", "", "", "1"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 3} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"d", 
      TagBox[GridBox[{
         {""}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{"Columns" -> {{
             GrayLevel[0.5]}}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.685705344896318*^9, 3.686040860476645*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"(", "III", ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Note", ":", " ", "i"}], "=", "p"}], ",", " ", 
      RowBox[{"j", "=", "q"}], ",", " ", 
      RowBox[{"k", "=", "r"}]}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T31", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "g", ",", "e", ",", "f", ",", "a", ",", "R", ",", "p", ",", "q"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "c", ",", "d", ",", "e", ",", "g", ",", "R", ",", "p", ",", "r"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "b", ",", "c", ",", "g", ",", "a", ",", "L", ",", "r", ",", "q"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T31p", "=", 
     RowBox[{"AlexpolyP", "[", "T31", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T32", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "g", ",", "e", ",", "f", ",", "a", ",", "L", ",", "q", ",", "p"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "c", ",", "d", ",", "e", ",", "g", ",", "L", ",", "r", ",", "p"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "b", ",", "c", ",", "g", ",", "a", ",", "R", ",", "q", ",", "r"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T32p", "=", 
     RowBox[{"AlexpolyP", "[", "T32", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T33", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "g", ",", "e", ",", "f", ",", "a", ",", "L", ",", "q", ",", "p"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "c", ",", "d", ",", "e", ",", "g", ",", "R", ",", "p", ",", "r"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "b", ",", "c", ",", "g", ",", "a", ",", "R", ",", "q", ",", "r"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T33p", "=", 
     RowBox[{"AlexpolyP", "[", "T33", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T34", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "g", ",", "e", ",", "f", ",", "a", ",", "R", ",", "p", ",", "q"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "c", ",", "d", ",", "e", ",", "g", ",", "L", ",", "r", ",", "p"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "b", ",", "c", ",", "g", ",", "a", ",", "L", ",", "r", ",", "q"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T34p", "=", 
     RowBox[{"AlexpolyP", "[", "T34", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T35", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "g", ",", "e", ",", "f", ",", "a", ",", "L", ",", "q", ",", "p"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "c", ",", "d", ",", "e", ",", "g", ",", "L", ",", "r", ",", "p"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "b", ",", "c", ",", "g", ",", "a", ",", "L", ",", "r", ",", "q"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T35p", "=", 
     RowBox[{"AlexpolyP", "[", "T35", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T36", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "g", ",", "e", ",", "f", ",", "a", ",", "R", ",", "p", ",", "q"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "c", ",", "d", ",", "e", ",", "g", ",", "R", ",", "p", ",", "r"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "b", ",", "c", ",", "g", ",", "a", ",", "R", ",", "q", ",", "r"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T36p", "=", 
     RowBox[{"AlexpolyP", "[", "T36", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"p", " ", "q"}], ")"}], 
          RowBox[{"-", "2"}]], "-", 
         RowBox[{
          SuperscriptBox["p", "2"], " ", 
          SuperscriptBox["q", "2"]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"T31p", "+", "T32p"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["q", "2"], " ", 
          SuperscriptBox["r", "2"]}], "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"q", " ", "r"}], ")"}], 
          RowBox[{"-", "2"}]]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"T33p", "+", "T34p"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["p", "2"], " ", 
          SuperscriptBox["r", 
           RowBox[{"-", "2"}]]}], "-", 
         RowBox[{
          SuperscriptBox["p", 
           RowBox[{"-", "2"}]], 
          SuperscriptBox["r", "2"]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"T35p", "+", "T36p"}], ")"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"h", "\[Rule]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"\[Delta]", "\[Rule]", "1"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6177120514814587`*^9, 3.6177121483339987`*^9}, {
  3.617712208136419*^9, 3.617712366448474*^9}, {3.6177124054907064`*^9, 
  3.617712479344931*^9}, {3.617712523647465*^9, 3.6177126254112854`*^9}, {
  3.6177127074889803`*^9, 3.617712851140197*^9}, {3.617712914042794*^9, 
  3.617713101930541*^9}, {3.617713154584553*^9, 3.617713352730886*^9}, {
  3.6177133966793995`*^9, 3.6177134012416606`*^9}, {3.617714077589346*^9, 
  3.6177140960243998`*^9}, {3.620893546138569*^9, 3.6208936125903697`*^9}, {
  3.643462430973219*^9, 3.643462468821322*^9}, {3.681909957109703*^9, 
  3.6819100006290216`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.617713344128394*^9, 3.6177133542449727`*^9}, 
   3.6177134018626957`*^9, 3.620893572575081*^9, 3.620893615900559*^9, 
   3.63896532681194*^9, 3.643462424327671*^9, 3.6434624703019247`*^9, 
   3.681910091294116*^9, 3.6839621345170107`*^9, 3.683970388193935*^9, 
   3.6839721782095127`*^9, 3.684481221978177*^9, 3.685705346282827*^9, 
   3.686040862180361*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"(", "IO", ")"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "This", " ", "is", " ", "clear", " ", "from", " ", "the", " ", 
     "definition"}], ",", " ", 
    RowBox[{
    "because", " ", "there", " ", "is", " ", "a", " ", "closed", " ", 
     "component", " ", "which", " ", "cannot", " ", "be", " ", "occupieed", 
     " ", "by", " ", "a", " ", 
     RowBox[{"marker", "."}]}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.617706737961543*^9, 3.6177067438598804`*^9}, {
   3.6177077573968515`*^9, 3.617708872976659*^9}, {3.617708942640643*^9, 
   3.6177089714162893`*^9}, {3.617709069091876*^9, 3.6177090906651096`*^9}, {
   3.6177091313114347`*^9, 3.6177091730778236`*^9}, {3.617709255244523*^9, 
   3.6177092580686846`*^9}, {3.6177093351470933`*^9, 3.617709391453314*^9}, {
   3.617709427007347*^9, 3.617709431792621*^9}, {3.6177095726146755`*^9, 
   3.617709611642908*^9}, {3.617709724145343*^9, 3.6177097365680532`*^9}, {
   3.617709811443336*^9, 3.6177098290833445`*^9}, {3.6177103277898693`*^9, 
   3.6177105225320077`*^9}, {3.6177105608431993`*^9, 3.617710712336864*^9}, {
   3.617710784258978*^9, 3.6177108091554017`*^9}, {3.6177108721810064`*^9, 
   3.6177108901910367`*^9}, {3.617711257627053*^9, 3.6177112908169513`*^9}, {
   3.6177116507995415`*^9, 3.6177116541487327`*^9}, 3.6177136930863533`*^9, {
   3.617714155152782*^9, 3.6177142371934743`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"(", "\[CapitalPhi]", ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Note", ":", " ", "i"}], "=", "p"}], ",", " ", 
      RowBox[{"j", "=", "q"}]}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cir", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "a", ",", "c", ",", "d", ",", "b", ",", "R", ",", "q", ",", "p"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "d", ",", "c", ",", "a", ",", "b", ",", "R", ",", "p", ",", "q"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"cirp", "=", 
    RowBox[{"AlexpolyP", "[", "cir", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"AlexpolytableP", "[", 
    RowBox[{"cir", ",", "cirp"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.617706722330649*^9, 3.617706732042204*^9}, {
   3.617714253707419*^9, 3.61771426176788*^9}, {3.6177142998570585`*^9, 
   3.6177143396723356`*^9}, {3.620893644207178*^9, 3.620893645512253*^9}, 
   3.6208938728812575`*^9, {3.638965332849285*^9, 3.6389653514753504`*^9}, {
   3.643462479273838*^9, 3.6434624796046057`*^9}, 3.681910097536193*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["p", 
   RowBox[{"-", "2"}]], "-", 
  SuperscriptBox["p", "2"]}]], "Output",
 CellChangeTimes->{{3.617714314689907*^9, 3.6177143213142858`*^9}, 
   3.6208936541697483`*^9, 3.6208938254675455`*^9, {3.6208938678519697`*^9, 
   3.620893873218277*^9}, 3.620894296400481*^9, {3.638965336896517*^9, 
   3.638965351906375*^9}, 3.643462498102611*^9, 3.681910105878189*^9, 
   3.683962136581544*^9, 3.6839703906486073`*^9, 3.683972183119729*^9, 
   3.684481223928982*^9, 3.685705348710722*^9, 3.686040863609344*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       TagBox[GridBox[{
          {"1"},
          {""},
          {""},
          {""},
          {
           RowBox[{"-", "1"}]}
         },
         AutoDelete->False,
         FrameStyle->Directive[
           Thickness[0.1], 
           AbsoluteDashing[{100, 0.01}], 
           GrayLevel[0.5]],
         GridBoxBackground->{
          "ColumnsIndexed" -> {1 -> GrayLevel[0.85]}, 
           "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
           "ItemsIndexed" -> {{3, 1} -> GrayLevel[0.5]}},
         GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
        "Grid"]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.617714314689907*^9, 3.6177143213142858`*^9}, 
   3.6208936541697483`*^9, 3.6208938254675455`*^9, {3.6208938678519697`*^9, 
   3.620893873218277*^9}, 3.620894296400481*^9, {3.638965336896517*^9, 
   3.638965351906375*^9}, 3.643462498102611*^9, 3.681910105878189*^9, 
   3.683962136581544*^9, 3.6839703906486073`*^9, 3.683972183119729*^9, 
   3.684481223928982*^9, 3.685705348710722*^9, 3.68604086361057*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", "H", ")"}], " ", "This", " ", "is", " ", "just", " ", 
     "normalisation"}], ";", " ", 
    RowBox[{
     RowBox[{"let", " ", "i"}], "=", 
     RowBox[{"p", " ", "be", " ", "the", " ", "loose", " ", "strand"}]}]}], 
   ",", " ", 
   RowBox[{"then", " ", "we", " ", "obtain", " ", 
    RowBox[{
     RowBox[{"(", "\[CapitalPhi]", ")"}], ".", " ", "So"}], " ", "the", " ", 
    "normalisation", " ", "factor", " ", "we", " ", "need", " ", "to", " ", 
    "introduce", " ", "to", " ", "get", " ", "the", " ", "Conway", " ", 
    "potential", " ", "function", " ", "is", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"c", "-", 
       SuperscriptBox["c", 
        RowBox[{"-", "1"}]]}], ")"}], 
     RowBox[{"-", "1"}]]}], ",", " ", 
   RowBox[{
   "where", " ", "c", " ", "is", " ", "the", " ", "colour", " ", "of", " ", 
    "the", " ", "loose", " ", 
    RowBox[{"strand", "."}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.617714382874807*^9, 3.617714419886924*^9}, {
  3.6177144527178016`*^9, 3.6177145129672475`*^9}, {3.6177146293269033`*^9, 
  3.617714775136243*^9}, {3.6208955302960563`*^9, 3.6208955417057085`*^9}, {
  3.683972317712126*^9, 3.6839723482714453`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation for the (2,-3)-pretzel tangle ", "Section",
 CellChangeTimes->{{3.683970886481442*^9, 3.683970889546365*^9}, {
  3.6839727453058567`*^9, 3.683972752850067*^9}, {3.6839731007790337`*^9, 
  3.683973112235179*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pt2m3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "h", ",", "f", ",", "b", ",", "c", ",", "R", ",", "q", ",", "q"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "g", ",", "f", ",", "h", ",", "c", ",", "R", ",", "q", ",", "q"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "d", ",", "f", ",", "g", ",", "c", ",", "R", ",", "q", ",", "q"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "a", ",", "e", ",", "f", ",", "d", ",", "R", ",", "q", ",", "p"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "f", ",", "e", ",", "a", ",", "b", ",", "R", ",", "p", ",", "q"}], 
      "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"pt2m3p", "=", 
   RowBox[{"AlexpolyGdh", "[", "pt2m3", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.6839709884284983`*^9}, {3.683971862243135*^9, 
   3.683971864340918*^9}, {3.683972791995537*^9, 3.683972845292199*^9}, {
   3.683972926663309*^9, 3.6839729302086906`*^9}, {3.684486346915266*^9, 
   3.684486348395269*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DConfig", "[", "pt2m3", "]"}]], "Input",
 CellChangeTimes->{{3.6839728952616987`*^9, 3.683972895438261*^9}}],

Cell[BoxData[
 GraphicsBox[{CircleBox[{0, 0}], 
   {Arrowheads[
    Medium], {
     ArrowBox[NCache[{{-2^Rational[-1, 2], 2^
         Rational[-1, 2]}, {-1.2727922061357855`, 
        1.2727922061357855`}}, {{-0.7071067811865475, 
       0.7071067811865475}, {-1.2727922061357855`, 1.2727922061357855`}}]], 
     InsetBox["p", 
      NCache[{-2^Rational[1, 2], 2^Rational[1, 2]}, {-1.4142135623730951`, 
       1.4142135623730951`}]], 
     InsetBox["1", {-0.4949747468305832, 0.4949747468305832}], 
     InsetBox["a", {-1.5, 1.8369701987210297`*^-16}]}, {
     ArrowBox[NCache[{{-1.2727922061357855`, -1.2727922061357855`}, {-2^
          Rational[-1, 2], -2^
          Rational[-1, 
            2]}}, {{-1.2727922061357855`, -1.2727922061357855`}, \
{-0.7071067811865475, -0.7071067811865475}}]], 
     InsetBox["p", 
      NCache[{-2^Rational[1, 2], -2^
         Rational[1, 2]}, {-1.4142135623730951`, -1.4142135623730951`}]], 
     InsetBox["2", {-0.4949747468305832, -0.4949747468305832}], 
     InsetBox["b", {-2.755455298081545*^-16, -1.5}]}, {
     ArrowBox[NCache[{{1.2727922061357855`, -1.2727922061357855`}, {
        2^Rational[-1, 2], -2^Rational[-1, 2]}}, {{
       1.2727922061357855`, -1.2727922061357855`}, {
       0.7071067811865475, -0.7071067811865475}}]], 
     InsetBox["q", 
      NCache[{2^Rational[1, 2], -2^Rational[1, 2]}, {
       1.4142135623730951`, -1.4142135623730951`}]], 
     InsetBox["3", {0.4949747468305832, -0.4949747468305832}], 
     InsetBox["c", {1.5, -3.6739403974420594`*^-16}]}, {
     ArrowBox[NCache[{{2^Rational[-1, 2], 2^Rational[-1, 2]}, {
        1.2727922061357855`, 1.2727922061357855`}}, {{0.7071067811865475, 
       0.7071067811865475}, {1.2727922061357855`, 1.2727922061357855`}}]], 
     InsetBox["q", 
      NCache[{2^Rational[1, 2], 2^Rational[1, 2]}, {1.4142135623730951`, 
       1.4142135623730951`}]], 
     InsetBox["4", {0.4949747468305832, 0.4949747468305832}], 
     InsetBox["d", {4.592425496802575*^-16, 1.5}]}, 
    {GrayLevel[0], Opacity[0], CircleBox[{0, 0}, 1.3]}}},
  ImageSize->Tiny]], "Output",
 CellChangeTimes->{3.683972895687952*^9, 3.6839729329907846`*^9, 
  3.684481229011672*^9, 3.684483033043828*^9, 3.6844887032847652`*^9, 
  3.68570535213831*^9, 3.686040866793023*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AlexpolytableGdh", "[", 
  RowBox[{"pt2m3", ",", "pt2m3p"}], "]"}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.683971015430806*^9}, {3.683971716447658*^9, 
   3.68397173563983*^9}, {3.683972861253587*^9, 3.683972864118195*^9}, 
   3.684482826883131*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"a", 
      TagBox[GridBox[{
         {
          RowBox[{"hgfae", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]]}], "", "", "", 
          RowBox[{
           RowBox[{
            RowBox[{"h", " ", "hfgae"}], 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", 
              FractionBox["3", "2"]}]]}], "+", 
           RowBox[{
            RowBox[{"h", " ", "hgfea"}], 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", 
              FractionBox["3", "2"]}]]}]}], "", "", "", 
          RowBox[{
           RowBox[{
            RowBox[{"fhgae", " ", 
             SuperscriptBox["h", "2"]}], 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", 
              FractionBox["3", "2"]}]]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["h", "2"], " ", "hfgea"}], 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", 
              FractionBox["3", "2"]}]]}]}], "", "", "", 
          RowBox[{
           RowBox[{"fhgea", " ", 
            SuperscriptBox["h", "3"]}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{1, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"b", 
      TagBox[GridBox[{
         {
          RowBox[{"hgfeb", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}], "", "", "", 
          RowBox[{
           RowBox[{"h", " ", "hfgeb"}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}], "", "", "", 
          RowBox[{
           RowBox[{
            RowBox[{"bhgef", " ", 
             SuperscriptBox["h", "3"]}], 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", "2"}]]}], "+", 
           RowBox[{
            RowBox[{"fhgeb", " ", 
             SuperscriptBox["h", "2"]}], 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", "1"}]]}]}]},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", 
          RowBox[{
           RowBox[{"bhgfe", " ", 
            SuperscriptBox["h", "4"]}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "2"}]]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 3} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"c", 
      TagBox[GridBox[{
         {
          RowBox[{"hgcef", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]]}], "", "", "", 
          RowBox[{
           RowBox[{"h", " ", "hcgef"}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]]}], "", "", "", 
          RowBox[{
           RowBox[{"chgef", " ", 
            SuperscriptBox["h", "2"]}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]]}]},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {
          RowBox[{
           RowBox[{"h", " ", "hgcfe"}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]]}], "", "", "", 
          RowBox[{
           RowBox[{
            SuperscriptBox["h", "2"], " ", "hcgfe"}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]]}], "", "", "", 
          RowBox[{
           RowBox[{"chgfe", " ", 
            SuperscriptBox["h", "3"]}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["3", "2"]}]]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {5 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 5} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"d", 
      TagBox[GridBox[{
         {
          RowBox[{"hgdef", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "2"}]]}], "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {
          RowBox[{
           RowBox[{
            RowBox[{"h", " ", "hgdfe"}], 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", "2"}]]}], "+", 
           RowBox[{"hgfde", 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", "1"}]]}]}], "", "", "", 
          RowBox[{
           RowBox[{"h", " ", "hfgde"}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}], "", "", "", 
          RowBox[{
           RowBox[{"fhgde", " ", 
            SuperscriptBox["h", "2"]}], 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.683971881515421*^9, {3.683971996653132*^9, 3.683972000366529*^9}, 
   3.6839728646449127`*^9, 3.68397293510982*^9, 3.68448123013764*^9, 
   3.684482827297224*^9, 3.684486333067401*^9, 3.6844887040891247`*^9, 
   3.6857053536101418`*^9, 3.686040868364216*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotGrid", "[", "pt2m3", "]"}]], "Input",
 CellChangeTimes->{{3.6389645931089745`*^9, 3.638964623829732*^9}, {
   3.638964775723419*^9, 3.6389648036940193`*^9}, {3.6389648742650557`*^9, 
   3.6389648938251743`*^9}, {3.6389649915927663`*^9, 
   3.6389649942399178`*^9}, {3.643448048780984*^9, 3.6434480633586607`*^9}, {
   3.6434482715092497`*^9, 3.643448271741086*^9}, {3.643448334073648*^9, 
   3.6434483395499496`*^9}, {3.643448753397462*^9, 3.643448753533633*^9}, {
   3.6434630180664167`*^9, 3.6434630181056967`*^9}, 3.643463093919751*^9, {
   3.643463689968041*^9, 3.643463698847226*^9}, {3.666725009416155*^9, 
   3.666725044100822*^9}, {3.666728016690969*^9, 3.666728017219928*^9}, {
   3.68061136507215*^9, 3.6806113658277817`*^9}, {3.6806128451619253`*^9, 
   3.680612847128676*^9}, {3.6839708708016777`*^9, 3.683970871846673*^9}, {
   3.683970974092408*^9, 3.683971036093151*^9}, {3.6839728764698277`*^9, 
   3.683972878686076*^9}, 3.686040617005341*^9, 3.686040871924872*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-3/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-3/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-3/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-3/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-3/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-3/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-3/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-3/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-3/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-3/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-3/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-3/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}]}
   },
   AutoDelete->False,
   FrameStyle->Directive[
     Thickness[0.1], 
     AbsoluteDashing[{100, 0.01}], 
     GrayLevel[0.5]],
   GridBoxBackground->{
    "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
     "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
     "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.683971037194088*^9, 3.683972011677722*^9, 
  3.6839728793013897`*^9, 3.683972937535593*^9, 3.684481232513813*^9, 
  3.684488705043048*^9, 3.685705355682908*^9, 3.6860408726862507`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", ",", 
     RowBox[{"-", "3"}]}], ")"}], "-", 
   RowBox[{
   "pretzel", " ", "with", " ", "orientation", " ", "of", " ", "q", " ", 
    "reversed"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.666341844729817*^9, 3.666341852585041*^9}, {
  3.68448693076931*^9, 3.6844869441296186`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Tm2x3r", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "d", ",", "a", ",", "e", ",", "f", ",", "L", ",", "q", ",", "p"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "e", ",", "a", ",", "b", ",", "f", ",", "L", ",", "p", ",", "q"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "g", ",", "c", ",", "d", ",", "f", ",", "R", ",", "q", ",", "q"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "h", ",", "c", ",", "g", ",", "f", ",", "R", ",", "q", ",", "q"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "b", ",", "c", ",", "h", ",", "f", ",", "R", ",", "q", ",", "q"}], 
      "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Tm2x3rp", "=", 
   RowBox[{"AlexpolyGd", "[", "Tm2x3r", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"AlexpolytableGd", "[", 
  RowBox[{"Tm2x3r", ",", "Tm2x3rp"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DotGrid", "[", "Tm2x3r", "]"}], "\[IndentingNewLine]", 
 RowBox[{"DConfig", "[", "Tm2x3r", "]"}]}], "Input",
 CellChangeTimes->{{3.681920066595212*^9, 3.6819201744653463`*^9}, {
   3.68192156084446*^9, 3.681921566012731*^9}, {3.681926387593512*^9, 
   3.681926396781588*^9}, 3.686040617015337*^9, 3.68604087690819*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"a", 
      TagBox[GridBox[{
         {
          RowBox[{"eaghf", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          RowBox[{
           RowBox[{"aeghf", 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", 
              FractionBox["1", "2"]}]]}], "+", 
           RowBox[{"eagfh", 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", 
              FractionBox["1", "2"]}]]}]}], "", "", "", 
          RowBox[{
           RowBox[{"aegfh", 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", 
              FractionBox["1", "2"]}]]}], "+", 
           RowBox[{"eafgh", 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", 
              FractionBox["1", "2"]}]]}]}], "", "", "", 
          RowBox[{"aefgh", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {1 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{1, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"b", 
      TagBox[GridBox[{
         {
          RowBox[{"ebghf", "+", 
           RowBox[{"efghb", 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", "1"}]]}]}], "", "", "", "ebgfh", "", "", "", 
          "ebfgh"},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {
          RowBox[{"feghb", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}], "", "", "", "", "", "", "", ""}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"c", 
      TagBox[GridBox[{
         {
          RowBox[{"efghc", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          RowBox[{"efgch", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          RowBox[{"efcgh", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}]},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {
          RowBox[{"feghc", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          RowBox[{"fegch", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}], "", "", "", 
          RowBox[{"fecgh", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", 
             FractionBox["1", "2"]}]]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {5 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 5} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]},
     {"d", 
      TagBox[GridBox[{
         {"", "", "", "", "", "", "", "", 
          RowBox[{"efdgh", 
           SuperscriptBox["\[Delta]", 
            RowBox[{"-", "1"}]]}]},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"", "", "", "", "", "", "", "", ""},
         {"deghf", "", "", "", "degfh", "", "", "", 
          RowBox[{"defgh", "+", 
           RowBox[{"fedgh", 
            SuperscriptBox["\[Delta]", 
             RowBox[{"-", "1"}]]}]}]}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          Thickness[0.1], 
          AbsoluteDashing[{100, 0.01}], 
          GrayLevel[0.5]],
        GridBoxBackground->{
         "ColumnsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
          "ItemsIndexed" -> {{3, 3} -> GrayLevel[0.5]}},
        GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.6844869461541843`*^9, 3.684487018141171*^9, 3.685705357234734*^9, {
   3.686040874210743*^9, 3.686040877529681*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"0\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"0\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"0\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1/2\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}], "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 0, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}]},
    {"\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \"\>", "\<\" \
\"\>", "\<\" \"\>"},
    {
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 0, 1], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"0\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"0\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, InsetBox[
        GraphicsBox[{
          {RGBColor[0, 1, 0], DiskBox[{0, 0}, 0.1]}, 
          {GrayLevel[0], 
           InsetBox["\<\"-1/2\"\>", 
            NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
          {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
         ImageSize->30], {15.75, -24.749999999999996`}, 
        ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], {}},
      ContentSelectable->True,
      ImageSize->30,
      PlotRangePadding->{6, 5}], "\<\" \"\>", 
     GraphicsBox[{{}, {InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"-1\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {16., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}], InsetBox[
         GraphicsBox[{
           {RGBColor[1, 1, 0], DiskBox[{0, 0}, 0.1]}, 
           {GrayLevel[0], 
            InsetBox["\<\"0\"\>", 
             NCache[{0, Rational[3, 7]}, {0, 0.42857142857142855`}]]}, 
           {GrayLevel[0], Opacity[0], DiskBox[{0, 0}, 0.2]}},
          ImageSize->30], {48., -24.749999999999996`}, 
         ImageScaled[{0.5, 0.5}], {30, 47.14285714285714}]}, {}},
      ContentSelectable->True,
      ImageSize->60,
      PlotRangePadding->{6, 5}]}
   },
   AutoDelete->False,
   FrameStyle->Directive[
     Thickness[0.1], 
     AbsoluteDashing[{100, 0.01}], 
     GrayLevel[0.5]],
   GridBoxBackground->{
    "ColumnsIndexed" -> {7 -> GrayLevel[0.85]}, 
     "RowsIndexed" -> {3 -> GrayLevel[0.85]}, 
     "ItemsIndexed" -> {{3, 7} -> GrayLevel[0.5]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.6844869461541843`*^9, 3.684487018141171*^9, 3.685705357234734*^9, {
   3.686040874210743*^9, 3.686040877596936*^9}}],

Cell[BoxData[
 GraphicsBox[{CircleBox[{0, 0}], 
   {Arrowheads[
    Medium], {
     ArrowBox[NCache[{{-2^Rational[-1, 2], 2^
         Rational[-1, 2]}, {-1.2727922061357855`, 
        1.2727922061357855`}}, {{-0.7071067811865475, 
       0.7071067811865475}, {-1.2727922061357855`, 1.2727922061357855`}}]], 
     InsetBox["p", 
      NCache[{-2^Rational[1, 2], 2^Rational[1, 2]}, {-1.4142135623730951`, 
       1.4142135623730951`}]], 
     InsetBox["1", {-0.4949747468305832, 0.4949747468305832}], 
     InsetBox["a", {-1.5, 1.8369701987210297`*^-16}]}, {
     ArrowBox[NCache[{{-1.2727922061357855`, -1.2727922061357855`}, {-2^
          Rational[-1, 2], -2^
          Rational[-1, 
            2]}}, {{-1.2727922061357855`, -1.2727922061357855`}, \
{-0.7071067811865475, -0.7071067811865475}}]], 
     InsetBox["p", 
      NCache[{-2^Rational[1, 2], -2^
         Rational[1, 2]}, {-1.4142135623730951`, -1.4142135623730951`}]], 
     InsetBox["2", {-0.4949747468305832, -0.4949747468305832}], 
     InsetBox["b", {-2.755455298081545*^-16, -1.5}]}, {
     ArrowBox[NCache[{{2^Rational[-1, 2], -2^Rational[-1, 2]}, {
        1.2727922061357855`, -1.2727922061357855`}}, {{
       0.7071067811865475, -0.7071067811865475}, {
       1.2727922061357855`, -1.2727922061357855`}}]], 
     InsetBox["q", 
      NCache[{2^Rational[1, 2], -2^Rational[1, 2]}, {
       1.4142135623730951`, -1.4142135623730951`}]], 
     InsetBox["3", {0.4949747468305832, -0.4949747468305832}], 
     InsetBox["c", {1.5, -3.6739403974420594`*^-16}]}, {
     ArrowBox[NCache[{{1.2727922061357855`, 1.2727922061357855`}, {
        2^Rational[-1, 2], 2^Rational[-1, 2]}}, {{1.2727922061357855`, 
       1.2727922061357855`}, {0.7071067811865475, 0.7071067811865475}}]], 
     InsetBox["q", 
      NCache[{2^Rational[1, 2], 2^Rational[1, 2]}, {1.4142135623730951`, 
       1.4142135623730951`}]], 
     InsetBox["4", {0.4949747468305832, 0.4949747468305832}], 
     InsetBox["d", {4.592425496802575*^-16, 1.5}]}, 
    {GrayLevel[0], Opacity[0], CircleBox[{0, 0}, 1.3]}}},
  ImageSize->Tiny]], "Output",
 CellChangeTimes->{
  3.6844869461541843`*^9, 3.684487018141171*^9, 3.685705357234734*^9, {
   3.686040874210743*^9, 3.686040877605301*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 974},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{595.1999999999999, 841.8},
"PrintingMargins"->{{25.653543585, 25.653543585}, {43.65354378, 43.65354378}}},
FrontEndVersion->"10.3 for Linux x86 (64-bit) (December 10, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, Visible -> False, 
  FrontEndVersion -> "10.3 for Linux x86 (64-bit) (December 10, 2015)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 189, 3, 93, "Title"],
Cell[772, 27, 825, 13, 91, "Text"],
Cell[CellGroupData[{
Cell[1622, 44, 396, 5, 65, "Section"],
Cell[CellGroupData[{
Cell[2043, 53, 308, 5, 32, "Input"],
Cell[2354, 60, 3062, 47, 443, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5465, 113, 177, 2, 65, "Section"],
Cell[5645, 117, 1910, 41, 143, "Input"],
Cell[CellGroupData[{
Cell[7580, 162, 1135, 17, 32, "Input"],
Cell[8718, 181, 4676, 174, 98, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13431, 360, 1081, 16, 32, "Input"],
Cell[14515, 378, 3385, 115, 81, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17937, 498, 1240, 21, 32, "Input"],
Cell[19180, 521, 1306, 33, 113, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20523, 559, 1086, 16, 32, "Input"],
Cell[21612, 577, 4931, 128, 366, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26580, 710, 1092, 16, 32, "Input"],
Cell[27675, 728, 5587, 149, 392, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33299, 882, 1140, 17, 32, "Input"],
Cell[34442, 901, 6421, 177, 392, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40900, 1083, 1033, 15, 32, "Input"],
Cell[41936, 1100, 12107, 274, 248, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54080, 1379, 980, 14, 32, "Input"],
Cell[55063, 1395, 2887, 53, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57987, 1453, 258, 5, 32, "Input"],
Cell[58248, 1460, 952, 24, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59237, 1489, 180, 4, 32, "Input"],
Cell[59420, 1495, 2175, 43, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61632, 1543, 253, 5, 32, "Input"],
Cell[61888, 1550, 17023, 370, 248, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78948, 1925, 184, 4, 32, "Input"],
Cell[79135, 1931, 1043, 27, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80215, 1963, 129, 2, 32, "Input"],
Cell[80347, 1967, 2177, 43, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82561, 2015, 151, 3, 32, "Input"],
Cell[82715, 2020, 27783, 605, 330, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[110547, 2631, 205, 2, 65, "Section"],
Cell[CellGroupData[{
Cell[110777, 2637, 2244, 49, 121, "Input"],
Cell[113024, 2688, 14537, 396, 171, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[127598, 3089, 2363, 51, 121, "Input"],
Cell[129964, 3142, 54583, 1499, 905, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[184596, 4647, 319, 5, 65, "Section"],
Cell[184918, 4654, 250, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[185193, 4663, 2246, 58, 143, "Input"],
Cell[187442, 4723, 2987, 88, 274, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190466, 4816, 6775, 197, 322, "Input"],
Cell[197244, 5015, 409, 6, 32, "Output"]
}, Open  ]],
Cell[197668, 5024, 1472, 26, 77, "Input"],
Cell[CellGroupData[{
Cell[199165, 5054, 1298, 33, 99, "Input"],
Cell[200466, 5089, 547, 10, 34, "Output"],
Cell[201016, 5101, 1715, 45, 124, "Output"]
}, Open  ]],
Cell[202746, 5149, 1280, 30, 79, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204063, 5184, 229, 3, 65, "Section"],
Cell[204295, 5189, 2089, 45, 165, "Input"],
Cell[CellGroupData[{
Cell[206409, 5238, 132, 2, 32, "Input"],
Cell[206544, 5242, 2257, 44, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[208838, 5291, 1071, 16, 32, "Input"],
Cell[209912, 5309, 7467, 209, 392, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[217416, 5523, 1009, 14, 32, "Input"],
Cell[218428, 5539, 12155, 274, 248, "Output"]
}, Open  ]],
Cell[230598, 5816, 360, 10, 32, "Input"],
Cell[CellGroupData[{
Cell[230983, 5830, 1487, 37, 231, "Input"],
Cell[232473, 5869, 5871, 163, 392, "Output"],
Cell[238347, 6034, 12084, 274, 248, "Output"],
Cell[250434, 6310, 2215, 44, 115, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

